@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -17,7 +17,7 @@
 #include <string.h>
 
 #include <modsecurity/modsecurity.h>
-#include <modsecurity/rules.h>
+#include <modsecurity/rules_set.h>
 #include "examples/reading_logs_via_rule_message/reading_logs_via_rule_message.h"
 
 
@@ -29,8 +29,8 @@ int main(int argc, char **argv) {
         return -1;
     }
 
-    *(argv++);
-    std::string rules(*argv);
+    char *rule = *(argv++);
+    std::string rules(rule);
     ReadingLogsViaRuleMessage rlvrm(request_header, request_uri, request_body,
         response_headers, response_body, ip, rules);
     rlvrm.process();
