@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -26,6 +26,7 @@
 #include <utility>
 #include <vector>
 #include <memory>
+#include <stack>
 #endif
 
 #include <stdlib.h>
@@ -37,7 +38,7 @@
 #ifndef __cplusplus
 typedef struct ModSecurity_t ModSecurity;
 typedef struct Transaction_t Transaction;
-typedef struct Rules_t Rules;
+typedef struct Rules_t RulesSet;
 #endif
 
 #include "modsecurity/anchored_set_variable.h"
@@ -47,12 +48,14 @@ typedef struct Rules_t Rules;
 #include "modsecurity/variable_value.h"
 #include "modsecurity/collection/collection.h"
 #include "modsecurity/variable_origin.h"
+#include "modsecurity/anchored_set_variable_translation_proxy.h"
+
 
 #ifndef NO_LOGS
 #define ms_dbg(b, c) \
   do { \
       if (m_rules && m_rules->m_debugLog && m_rules->m_debugLog->m_debugLevel >= b) { \
-          m_rules->debug(b, m_id, m_uri, c); \
+          m_rules->debug(b, *m_id.get(), m_uri, c); \
       } \
   } while (0);
 #else
@@ -98,7 +101,7 @@ namespace modsecurity {
 
 class ModSecurity;
 class Transaction;
-class Rules;
+class RulesSet;
 class RuleMessage;
 namespace actions {
 class Action;
@@ -109,6 +112,7 @@ enum AllowType : int;
 namespace RequestBodyProcessor {
 class XML;
 class JSON;
+class MultipartPartTmpFile;
 }
 namespace operators {
 class Operator;
@@ -118,10 +122,7 @@ class Operator;
 class TransactionAnchoredVariables {
  public:
     explicit TransactionAnchoredVariables(Transaction *t)
-        : m_variableArgsNames(t, "ARGS_NAMES"),
-        m_variableArgsGetNames(t, "ARGS_GET_NAMES"),
-        m_variableArgsPostNames(t, "ARGS_POST_NAMES"),
-        m_variableRequestHeadersNames(t, "REQUEST_HEADERS_NAMES"),
+        : m_variableRequestHeadersNames(t, "REQUEST_HEADERS_NAMES"),
         m_variableResponseContentType(t, "RESPONSE_CONTENT_TYPE"),
         m_variableResponseHeadersNames(t, "RESPONSE_HEADERS_NAMES"),
         m_variableARGScombinedSize(t, "ARGS_COMBINED_SIZE"),
@@ -199,12 +200,12 @@ class TransactionAnchoredVariables {
         m_variableGeo(t, "GEO"),
         m_variableRequestCookiesNames(t, "REQUEST_COOKIES_NAMES"),
         m_variableFilesTmpNames(t, "FILES_TMPNAMES"),
-        m_variableOffset(0)
+        m_variableOffset(0),
+        m_variableArgsNames("ARGS_NAMES", &m_variableArgs),
+        m_variableArgsGetNames("ARGS_GET_NAMES", &m_variableArgsGet),
+        m_variableArgsPostNames("ARGS_POST_NAMES", &m_variableArgsPost)
         { }
 
-    AnchoredSetVariable m_variableArgsNames;
-    AnchoredSetVariable m_variableArgsGetNames;
-    AnchoredSetVariable m_variableArgsPostNames;
     AnchoredSetVariable m_variableRequestHeadersNames;
     AnchoredVariable m_variableResponseContentType;
     AnchoredSetVariable m_variableResponseHeadersNames;
@@ -282,17 +283,54 @@ class TransactionAnchoredVariables {
     AnchoredSetVariable m_variableFilesTmpNames;
 
     int m_variableOffset;
+
+    AnchoredSetVariableTranslationProxy m_variableArgsNames;
+    AnchoredSetVariableTranslationProxy m_variableArgsGetNames;
+    AnchoredSetVariableTranslationProxy m_variableArgsPostNames;
 };
 
+class TransactionSecMarkerManagement {
+ public:
+    bool isInsideAMarker() const {
+        if (m_marker) {
+            return true;
+        }
+
+        return false;
+    }
+
+    std::shared_ptr<std::string> getCurrentMarker() const {
+        if (m_marker) {
+            return m_marker;
+        } else {
+            throw;
+        }
+    }
+
+    void removeMarker() {
+        m_marker.reset();
+    }
+
+    void addMarker(const std::shared_ptr<std::string> &name) {
+        m_marker = name;
+    }
+
+ private:
+    std::shared_ptr<std::string> m_marker;
+};
 
 /** @ingroup ModSecurity_CPP_API */
-class Transaction : public TransactionAnchoredVariables {
+class Transaction : public TransactionAnchoredVariables, public TransactionSecMarkerManagement {
  public:
-    Transaction(ModSecurity *transaction, Rules *rules, void *logCbData);
-    Transaction(ModSecurity *transaction, Rules *rules, char *id,
+    Transaction(ModSecurity *transaction, RulesSet *rules, void *logCbData);
+    Transaction(ModSecurity *transaction, RulesSet *rules, char *id,
         void *logCbData);
     ~Transaction();
 
+    Transaction ( const Transaction & ) = delete;
+    bool operator ==(const Transaction &b) const { return false; };
+    Transaction &operator =(const Transaction &b) const = delete;
+
     /** TODO: Should be an structure that fits an IP address */
     int processConnection(const char *client, int cPort,
         const char *server, int sPort);
@@ -355,7 +393,7 @@ class Transaction : public TransactionAnchoredVariables {
     bool extractArguments(const std::string &orig, const std::string& buf,
         size_t offset);
 
-    const char *getResponseBody();
+    const char *getResponseBody() const;
     size_t getResponseBodyLength();
     size_t getRequestBodyLength();
 
@@ -364,7 +402,7 @@ class Transaction : public TransactionAnchoredVariables {
 #endif
     void serverLog(std::shared_ptr<RuleMessage> rm);
 
-    int getRuleEngineState();
+    int getRuleEngineState() const;
 
     std::string toJSON(int parts);
     std::string toOldAuditLogFormat(int parts, const std::string &trailer);
@@ -386,7 +424,7 @@ class Transaction : public TransactionAnchoredVariables {
     /**
      * Holds the client IP address.
      */
-    std::string m_clientIpAddress;
+    std::shared_ptr<std::string> m_clientIpAddress;
 
     /**
      * Holds the HTTP version: 1.2, 2.0, 3.0 and so on....
@@ -396,7 +434,7 @@ class Transaction : public TransactionAnchoredVariables {
     /**
      * Holds the server IP Address
      */
-    std::string m_serverIpAddress;
+    std::shared_ptr<std::string> m_serverIpAddress;
 
     /**
      * Holds the raw URI that was requested.
@@ -406,7 +444,7 @@ class Transaction : public TransactionAnchoredVariables {
     /**
      * Holds the URI that was requests (without the query string).
      */
-    std::string m_uri_no_query_string_decoded;
+    std::shared_ptr<std::string> m_uri_no_query_string_decoded;
 
     /**
      * Holds the combined size of all arguments, later used to fill the
@@ -455,7 +493,7 @@ class Transaction : public TransactionAnchoredVariables {
     /**
      * Rules object utilized during this specific transaction.
      */
-    Rules *m_rules;
+    RulesSet *m_rules;
 
     /**
      *
@@ -512,13 +550,7 @@ class Transaction : public TransactionAnchoredVariables {
      * Contains the unique ID of the transaction. Use by the variable
 	 * `UNIQUE_ID'. This unique id is also saved as part of the AuditLog.
      */
-    std::string m_id;
-
-    /**
-     * Holds the SecMarker name that this transaction should wait to perform
-     * rules evaluation again.
-     */
-    std::string m_marker;
+    std::shared_ptr<std::string> m_id;
 
     /**
      * Holds the amount of rules that should be skipped. If bigger than 0 the
@@ -583,6 +615,8 @@ class Transaction : public TransactionAnchoredVariables {
     std::string m_variableTimeWDay;
     std::string m_variableTimeYear;
 
+    std::vector<std::shared_ptr<RequestBodyProcessor::MultipartPartTmpFile>> m_multipartPartTmpFiles;
+
  private:
     /**
      * Pointer to the callback function that will be called to fill
@@ -600,11 +634,11 @@ extern "C" {
 
 /** @ingroup ModSecurity_C_API */
 Transaction *msc_new_transaction(ModSecurity *ms,
-    Rules *rules, void *logCbData);
+    RulesSet *rules, void *logCbData);
 
 /** @ingroup ModSecurity_C_API */
 Transaction *msc_new_transaction_with_id(ModSecurity *ms,
-    Rules *rules, char *id, void *logCbData);
+    RulesSet *rules, char *id, void *logCbData);
 
 /** @ingroup ModSecurity_C_API */
 int msc_process_connection(Transaction *transaction,
