@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -18,7 +18,6 @@
 
 #include "modsecurity/actions/action.h"
 #include "modsecurity/transaction.h"
-#include "modsecurity/rules.h"
 #include "modsecurity/rule_message.h"
 
 #ifndef SRC_ACTIONS_DISRUPTIVE_DROP_H_
@@ -31,9 +30,9 @@ namespace disruptive {
 
 class Drop : public Action {
  public:
-    explicit Drop(std::string action) : Action(action) { }
+    explicit Drop(const std::string &action) : Action(action) { }
 
-    bool evaluate(Rule *rule, Transaction *transaction,
+    bool evaluate(RuleWithActions *rule, Transaction *transaction,
         std::shared_ptr<RuleMessage> rm) override;
     bool isDisruptive() override { return true; }
 };
