@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -32,13 +32,13 @@ namespace actions {
 
 class InitCol : public Action {
  public:
-    explicit InitCol(std::string action) : Action(action) { }
+    explicit InitCol(const std::string &action) : Action(action) { }
 
-    InitCol(std::string action, std::unique_ptr<RunTimeString> z)
+    InitCol(const std::string &action, std::unique_ptr<RunTimeString> z)
         : Action(action, RunTimeOnlyIfMatchKind),
             m_string(std::move(z)) { }
 
-    bool evaluate(Rule *rule, Transaction *transaction) override;
+    bool evaluate(RuleWithActions *rule, Transaction *transaction) override;
     bool init(std::string *error) override;
  private:
     std::string m_collection_key;
