@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -32,7 +32,7 @@ namespace actions {
 namespace transformations {
 
 
-std::string Base64DecodeExt::evaluate(std::string value,
+std::string Base64DecodeExt::evaluate(const std::string &value,
     Transaction *transaction) {
     std::string ret = Utils::Base64::decode_forgiven(value);
 
