@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -31,9 +31,9 @@ namespace transformations {
 
 class CssDecode : public Transformation {
  public:
-    explicit CssDecode(std::string action)
+    explicit CssDecode(const std::string &action) 
         : Transformation(action) { }
-    std::string evaluate(std::string exp,
+    std::string evaluate(const std::string &exp,
         Transaction *transaction) override;
 
     static int css_decode_inplace(unsigned char *input, int64_t input_len);
