@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -30,8 +30,10 @@ namespace transformations {
 
 class Trim : public Transformation {
  public:
-    explicit Trim(std::string action);
-    std::string evaluate(std::string exp,
+
+    explicit Trim(const std::string &action) ;
+
+    std::string evaluate(const std::string &exp,
         Transaction *transaction) override;
 
     std::string *ltrim(std::string *s);
