@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -31,13 +31,14 @@ namespace actions {
 namespace transformations {
 
 
-TrimRight::TrimRight(std::string action)
+TrimRight::TrimRight(const std::string &action) 
     : Trim(action) {
     this->action_kind = 1;
 }
 
-std::string TrimRight::evaluate(std::string value,
+std::string TrimRight::evaluate(const std::string &val,
     Transaction *transaction) {
+    std::string value(val);
     return *this->rtrim(&value);
 }
 
