@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -23,16 +23,16 @@ namespace modsecurity {
 namespace operators {
 
 
-bool EndsWith::evaluate(Transaction *transaction, Rule *rule,
-    const std::string &input, std::shared_ptr<RuleMessage> ruleMessage) {
+bool EndsWith::evaluate(Transaction *transaction, RuleWithActions *rule,
+    const std::string &str, std::shared_ptr<RuleMessage> ruleMessage) {
     bool ret = false;
     std::string p(m_string->evaluate(transaction));
 
-    if (input.length() >= p.length()) {
-        ret = (0 == input.compare(input.length() - p.length(),
+    if (str.length() >= p.length()) {
+        ret = (0 == str.compare(str.length() - p.length(),
             p.length(), p));
         if (ret) {
-            logOffset(ruleMessage, input.length() - p.length(),
+            logOffset(ruleMessage, str.length() - p.length(),
                       p.size());
         }
     }
