@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -15,21 +15,22 @@
 
 #include "src/parser/driver.h"
 
+#include "modsecurity/rules_set_properties.h"
 #include "src/parser/seclang-parser.hh"
 #include "modsecurity/audit_log.h"
-#include "modsecurity/rules_properties.h"
+#include "modsecurity/rule_marker.h"
 
 using modsecurity::audit_log::AuditLog;
-using modsecurity::Rule;
+using modsecurity::RuleWithOperator;
 
 namespace modsecurity {
 namespace Parser {
 
 Driver::Driver()
-  : RulesProperties(),
+  : RulesSetProperties(),
   trace_scanning(false),
   trace_parsing(false),
-  lastRule(NULL) { }
+  m_lastRule(nullptr) { }
 
 
 Driver::~Driver() {
@@ -41,86 +42,75 @@ Driver::~Driver() {
 }
 
 
-int Driver::addSecMarker(std::string marker) {
+int Driver::addSecMarker(std::string marker, std::unique_ptr<std::string> fileName, int lineNumber) {
+    // FIXME: we might move this to the parser.
     for (int i = 0; i < modsecurity::Phases::NUMBER_OF_PHASES; i++) {
-        Rule *rule = new Rule(marker);
-        rule->m_phase = i;
-        m_rules[i].push_back(rule);
+        RuleMarker *r = new RuleMarker(marker, std::unique_ptr<std::string>(new std::string(*fileName)), lineNumber);
+        std::unique_ptr<RuleMarker> rule(r);
+        rule->setPhase(i);
+        m_rulesSetPhases.insert(std::move(rule));
     }
     return 0;
 }
 
 
-int Driver::addSecAction(Rule *rule) {
-    if (rule->m_phase >= modsecurity::Phases::NUMBER_OF_PHASES) {
-        m_parserError << "Unknown phase: " << std::to_string(rule->m_phase);
+int Driver::addSecAction(std::unique_ptr<RuleWithActions> rule) {
+    if (rule->getPhase() >= modsecurity::Phases::NUMBER_OF_PHASES) {
+        m_parserError << "Unknown phase: " << std::to_string(rule->getPhase());
         m_parserError << std::endl;
         return false;
     }
 
-    m_rules[rule->m_phase].push_back(rule);
+    m_rulesSetPhases.insert(std::move(rule));
 
     return true;
 }
 
 
-int Driver::addSecRuleScript(RuleScript *rule) {
-    m_rules[rule->m_phase].push_back(rule);
+int Driver::addSecRuleScript(std::unique_ptr<RuleScript> rule) {
+    m_rulesSetPhases.insert(std::move(rule));
     return true;
 }
 
 
-int Driver::addSecRule(Rule *rule) {
-    if (rule->m_phase >= modsecurity::Phases::NUMBER_OF_PHASES) {
-        m_parserError << "Unknown phase: " << std::to_string(rule->m_phase);
+int Driver::addSecRule(std::unique_ptr<RuleWithActions> r) {
+    if (r->getPhase() >= modsecurity::Phases::NUMBER_OF_PHASES) {
+        m_parserError << "Unknown phase: " << std::to_string(r->getPhase());
         m_parserError << std::endl;
         return false;
     }
 
-    if (lastRule && lastRule->m_chained) {
-        if (lastRule->m_chainedRuleChild == NULL) {
-            rule->m_phase = lastRule->m_phase;
-            if (rule->m_theDisruptiveAction) {
-                m_parserError << "Disruptive actions can only be specified by";
-                m_parserError << " chain starter rules.";
-                return false;
-            }
-            lastRule->m_chainedRuleChild = rule;
-            rule->m_chainedRuleParent = lastRule;
-            return true;
-        } else {
-            Rule *a = lastRule->m_chainedRuleChild;
-            while (a->m_chained && a->m_chainedRuleChild != NULL) {
-                a = a->m_chainedRuleChild;
-            }
-            if (a->m_chained && a->m_chainedRuleChild == NULL) {
-                a->m_chainedRuleChild = rule;
-                rule->m_chainedRuleParent = a;
-                if (a->m_theDisruptiveAction) {
-                    m_parserError << "Disruptive actions can only be ";
-                    m_parserError << "specified by chain starter rules.";
-                    return false;
-                }
-                return true;
-            }
+    /* is it a chained rule? */
+    if (m_lastRule != nullptr && m_lastRule->isChained()) {
+        r->setPhase(m_lastRule->getPhase());
+        if (r->hasDisruptiveAction()) {
+            m_parserError << "Disruptive actions can only be specified by";
+            m_parserError << " chain starter rules.";
+            return false;
         }
+        m_lastRule->m_chainedRuleChild = std::move(r);
+        m_lastRule->m_chainedRuleChild->m_chainedRuleParent = m_lastRule;
+        m_lastRule = m_lastRule->m_chainedRuleChild.get();
+        return true;
     }
 
-
+    std::shared_ptr<RuleWithActions> rule(std::move(r));
     /*
      * Checking if the rule has an ID and also checking if this ID is not used
      * by other rule
      */
     if (rule->m_ruleId == 0) {
         m_parserError << "Rules must have an ID. File: ";
-        m_parserError << rule->m_fileName << " at line: ";
-        m_parserError << std::to_string(rule->m_lineNumber) << std::endl;
+        m_parserError << rule->getFileName() << " at line: ";
+        m_parserError << std::to_string(rule->getLineNumber()) << std::endl;
         return false;
     }
+
     for (int i = 0; i < modsecurity::Phases::NUMBER_OF_PHASES; i++) {
-        std::vector<Rule *> rules = m_rules[i];
-        for (int j = 0; j < rules.size(); j++) {
-            if (rules[j]->m_ruleId == rule->m_ruleId) {
+        Rules *rules = m_rulesSetPhases[i];
+        for (int j = 0; j < rules->size(); j++) {
+            RuleWithOperator *lr = dynamic_cast<RuleWithOperator *>(rules->at(j).get());
+            if (lr && lr->m_ruleId == rule->m_ruleId) {
                 m_parserError << "Rule id: " << std::to_string(rule->m_ruleId) \
                     << " is duplicated" << std::endl;
                 return false;
@@ -128,14 +118,15 @@ int Driver::addSecRule(Rule *rule) {
         }
     }
 
-    lastRule = rule;
-    m_rules[rule->m_phase].push_back(rule);
+    m_lastRule = rule.get();
+    m_rulesSetPhases.insert(rule);
+
     return true;
 }
 
 
 int Driver::parse(const std::string &f, const std::string &ref) {
-    lastRule = NULL;
+    m_lastRule = nullptr;
     loc.push_back(new yy::location());
     if (ref.empty()) {
         loc.back()->begin.filename = loc.back()->end.filename = new std::string("<<reference missing or not informed>>");
@@ -154,6 +145,19 @@ int Driver::parse(const std::string &f, const std::string &ref) {
     int res = parser.parse();
     scan_end();
 
+    /*
+     * need to check for rules marked as chained but without
+     * a chained rule.
+     *
+     */
+    /*
+    if (m_lastRule != nullptr && m_lastRule->isChained()) {
+        m_parserError << "Last rule is marked as chained but there " \
+            "isn't a subsequent rule." << std::endl;
+        return false;
+    }
+    */
+
     /*
     if (m_auditLog->init(&error) == false) {
         m_parserError << "Problems while initializing the audit logs: " \
