@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -56,8 +56,12 @@ void GeoLookup::cleanUp() {
 
 bool GeoLookup::setDataBase(const std::string& filePath,
     std::string *err) {
+#ifdef WITH_MAXMIND
     std::string intMax;
+#endif
+#ifdef WITH_GEOIP
     std::string intGeo;
+#endif
 
 #ifdef WITH_MAXMIND
     int status = MMDB_open(filePath.c_str(), MMDB_MODE_MMAP, &mmdb);
@@ -70,7 +74,7 @@ bool GeoLookup::setDataBase(const std::string& filePath,
 
 #ifdef WITH_GEOIP
     if (m_version == NOT_LOADED) {
-        m_gi = GeoIP_open(filePath.c_str(), GEOIP_INDEX_CACHE);
+        m_gi = GeoIP_open(filePath.c_str(), GEOIP_MEMORY_CACHE);
         if (m_gi == NULL) {
             intGeo.append("GeoIP: Can't open: " + filePath + ".");
         } else {
@@ -85,19 +89,22 @@ bool GeoLookup::setDataBase(const std::string& filePath,
 #ifdef WITH_MAXMIND
         err->append(" libMaxMind");
 #endif
-
 #ifdef WITH_GEOIP
         err->append(" GeoIP");
 #endif
         err->append(".");
 
-        if (intMax.size() > 0) {
+#ifdef WITH_MAXMIND
+        if (!intMax.empty()) {
             err->append(" " + intMax);
-
         }
-        if (intGeo.size() > 0) {
+#endif
+#ifdef WITH_GEOIP
+        if (!intGeo.empty()) {
             err->append(" " + intGeo);
         }
+#endif
+
         return false;
     }
 
@@ -106,7 +113,7 @@ bool GeoLookup::setDataBase(const std::string& filePath,
 
 
 bool GeoLookup::lookup(const std::string& target, Transaction *trans,
-    std::function<bool(int, std::string)> debug) {
+    std::function<bool(int, const std::string &)> debug) const {
 
     if (m_version == NOT_LOADED) {
         if (debug) {
@@ -120,7 +127,6 @@ bool GeoLookup::lookup(const std::string& target, Transaction *trans,
     if (m_version == VERSION_MAXMIND) {
         int gai_error, mmdb_error;
         MMDB_lookup_result_s r;
-        int status;
 
         r = MMDB_lookup_string(&mmdb, target.c_str(), &gai_error, &mmdb_error);
 
@@ -145,7 +151,7 @@ bool GeoLookup::lookup(const std::string& target, Transaction *trans,
         } else {
             MMDB_entry_data_s entry_data;
 
-            status = MMDB_get_value(&r.entry, &entry_data,
+            int status = MMDB_get_value(&r.entry, &entry_data,
                 "country", "iso_code", NULL);
             if (status == MMDB_SUCCESS && entry_data.has_data) {
                 trans->m_variableGeo.set("COUNTRY_CODE",
