@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -23,9 +23,8 @@
 #include <list>
 #include <algorithm>
 
+#include "modsecurity/rules_set.h"
 #include "modsecurity/modsecurity.h"
-#include "modsecurity/rules.h"
-
 #include "test/common/modsecurity_test.h"
 #include "test/common/colors.h"
 #include "test/regression/regression_test.h"
@@ -59,6 +58,30 @@ bool contains(const std::string &s, const std::string &pattern) {
     return ret;
 }
 
+void clearAuditLog(const std::string &filename) {
+    if (!filename.empty()) {
+        std::ifstream file;
+        file.open(filename.c_str(), std::ifstream::out | std::ifstream::trunc);
+        if (!file.is_open() || file.fail()) {
+            std::cout << std::endl << "Failed to clear previous contents of audit log: " \
+                << filename << std::endl;
+        }
+        file.close();
+    }
+}
+std::string getAuditLogContent(const std::string &filename) {
+    std::stringstream buffer;
+    if (!filename.empty()) {
+        try {
+           std::ifstream t(filename);
+           buffer << t.rdbuf();
+        } catch (...) {
+            std::cout << "Failed to read file:" << filename << std::endl;
+        }
+    }
+    return buffer.str();
+}
+
 
 void actions(ModSecurityTestResults<RegressionTest> *r,
     modsecurity::Transaction *a, std::stringstream *serverLog) {
@@ -99,7 +122,7 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
     for (RegressionTest *t : *tests) {
         CustomDebugLog *debug_log = new CustomDebugLog();
         modsecurity::ModSecurity *modsec = NULL;
-        modsecurity::Rules *modsec_rules = NULL;
+        modsecurity::RulesSet *modsec_rules = NULL;
         modsecurity::Transaction *modsec_transaction = NULL;
         ModSecurityTestResults<RegressionTest> r;
         std::stringstream serverLog;
@@ -148,7 +171,7 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
         modsec->setConnectorInformation("ModSecurity-regression v0.0.1-alpha" \
             " (ModSecurity regression test utility)");
         modsec->setServerLogCb(logCb);
-        modsec_rules = new modsecurity::Rules(debug_log);
+        modsec_rules = new modsecurity::RulesSet(debug_log);
 
         bool found = true;
         if (t->resource.empty() == false) {
@@ -188,7 +211,7 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
                  */
                 if (test->m_automake_output) {
                     std::cout << ":test-result: FAIL " << filename \
-                        << ":" << t->name << std::endl;
+                        << ":" << t->name << ":" << *count << std::endl;
                 } else {
                     std::cout << KRED << "failed!" << RESET << std::endl;
                 }
@@ -231,7 +254,7 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
                 /* Parser error was expected, but with a different content */
                 if (test->m_automake_output) {
                     std::cout << ":test-result: FAIL " << filename \
-                        << ":" << t->name << std::endl;
+                        << ":" << t->name << ":" << *count << std::endl;
                 } else {
                     std::cout << KRED << "failed!" << RESET << std::endl;
                 }
@@ -257,7 +280,7 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
             if (t->parser_error.empty() == false) {
                 if (test->m_automake_output) {
                     std::cout << ":test-result: FAIL " << filename \
-                        << ":" << t->name << std::endl;
+                        << ":" << t->name << ":" << *count << std::endl;
                 } else {
                     std::cout << KRED << "failed!" << RESET << std::endl;
                     std::cout << KWHT << "Expected a parser error." \
@@ -279,6 +302,8 @@ void perform_unit_test(ModSecurityTest<RegressionTest> *test,
         modsec_transaction = new modsecurity::Transaction(modsec, modsec_rules,
             &serverLog);
 
+        clearAuditLog(modsec_transaction->m_rules->m_auditLog->m_path1);
+
         modsec_transaction->processConnection(t->clientIp.c_str(),
             t->clientPort, t->serverIp.c_str(), t->serverPort);
 
@@ -362,7 +387,7 @@ end:
             if (!d->contains(t->debug_log)) {
                 if (test->m_automake_output) {
                     std::cout << ":test-result: FAIL " << filename \
-                        << ":" << t->name << std::endl;
+                        << ":" << t->name << ":" << *count << std::endl;
                 } else {
                     std::cout << KRED << "failed!" << RESET << std::endl;
                 }
@@ -374,7 +399,7 @@ end:
             } else if (r.status != t->http_code) {
                 if (test->m_automake_output) {
                     std::cout << ":test-result: FAIL " << filename \
-                        << ":" << t->name << std::endl;
+                        << ":" << t->name << ":" << *count << std::endl;
                 } else {
                     std::cout << KRED << "failed!" << RESET << std::endl;
                 }
@@ -394,6 +419,19 @@ end:
                 testRes->reason << KWHT << "Expecting: " << RESET \
                     << t->error_log + "";
                 testRes->passed = false;
+            } else if (!t->audit_log.empty()
+                && !contains(getAuditLogContent(modsec_transaction->m_rules->m_auditLog->m_path1), t->audit_log)) {
+                if (test->m_automake_output) {
+                    std::cout << ":test-result: FAIL " << filename \
+                        << ":" << t->name << ":" << *count << std::endl;
+                } else {
+                    std::cout << KRED << "failed!" << RESET << std::endl;
+                }
+                testRes->reason << "Audit log was not matching the " \
+                    << "expected results." << std::endl;
+                testRes->reason << KWHT << "Expecting: " << RESET \
+                    << t->audit_log + "";
+                testRes->passed = false;
             } else {
                 if (test->m_automake_output) {
                     std::cout << ":test-result: PASS " << filename \
@@ -411,6 +449,8 @@ end:
                 testRes->reason << d->log_messages() << std::endl;
                 testRes->reason << KWHT << "Error log:" << RESET << std::endl;
                 testRes->reason << serverLog.str() << std::endl;
+                testRes->reason << KWHT << "Audit log:" << RESET << std::endl;
+                testRes->reason << getAuditLogContent(modsec_transaction->m_rules->m_auditLog->m_path1) << std::endl;
             }
         }
 
